@@ -5,7 +5,8 @@ import subprocess
 import requests
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
-from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery
+from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
+from jnius import autoclass
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -19,28 +20,50 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
-        self.add_file_to_hedera(raw_json)
-        if WEBEX_ROOM:
-            self.send_webex_notification()
+        if 'eth_admin_fec_state' in raw_json:
+            json_dict = json.loads(raw_json)
+            print(json_dict)
+            for interface in enumerate(json_dict.get()):
+                if interface == 0:
+                    self.add_file_to_hedera(interface)
+                else:
+                    self.append_file_to_hedera(interface)
+            print(self.receipt.toString())
+
+            query = FileInfoQuery().setFileId(self.fileId)
+            info = query.execute(self.client)
+            print("File size according to `FileInfoQuery`: ", info.size)            
+            if WEBEX_ROOM:
+                self.send_webex_notification()
+        else:
+            self.add_file_to_hedera(raw_json)
+            if WEBEX_ROOM:
+                self.send_webex_notification()
         
     def py2output(self):
         self.output = subprocess.run(["python", "call_clid.py", self.command], capture_output=True)
 
     def add_file_to_hedera(self, raw_json):
-        client = Client.forTestnet()
-        client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
+        self.client = Client.forTestnet()
+        self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
         fileContents = raw_json
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(client)
         print("nodeId: ",  resp.nodeId.toString())
         self.nodeId = resp.nodeId.toString()
-        receipt = resp.getReceipt(client)
+        receipt = resp.getReceipt(self.client)
         self.fileId = receipt.fileId
         print("file: ",  self.fileId.toString())
-        query = FileContentsQuery()
-        contents = query.setFileId(self.fileId).execute(client)
-        json_contents = json.loads(contents.toStringUtf8())
-        print(json_contents)        
+
+    def append_file_to_hedera(self, interface):
+        tran = (FileAppendTransaction()
+                .setFileId(self.fileId)
+                .setContents(interface)
+                .setMaxChunks(128)
+                .setMaxTransactionFee(Hbar(2))
+                .freezeWith(self.client))
+        resp = tran.execute(self.client)
+        self.receipt = resp.getReceipt(self.client)
 
     def send_webex_notification(self):
         template_dir = Path(__file__).resolve().parent
